@@ -1,7 +1,7 @@
 import json
 from settings import settings
 from office365.runtime.auth.authentication_context import AuthenticationContext
-from office365.runtime.utilities.request_options import RequestOptions
+from office365.runtime.http.request_options import RequestOptions
 from office365.sharepoint.client_context import ClientContext
 
 if __name__ == '__main__':
