@@ -48,8 +48,8 @@ class User(DirectoryObject):
         qry = ServiceOperationQuery(self, "sendmail", None, message)
         self.context.add_query(qry)
 
-    def set_property(self, name, value, serializable=True):
-        super(User, self).set_property(name, value, serializable)
+    def set_property(self, name, value, persist_changes=True):
+        super(User, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
         if self._resource_path is None:
             if name == "id" or name == "userPrincipalName":
