@@ -1,8 +1,9 @@
 from office365.runtime.client_query import UpdateEntityQuery, DeleteEntityQuery
 from office365.runtime.client_runtime_context import ClientRuntimeContext
+from office365.runtime.odata.odata_request import ODataRequest
 from office365.runtime.odata.v4_json_format import V4JsonFormat
 from office365.runtime.resource_path import ResourcePath
-from office365.runtime.utilities.http_method import HttpMethod
+from office365.runtime.http.http_method import HttpMethod
 from office365.directory.user import User
 
 
@@ -12,11 +13,11 @@ class OutlookClient(ClientRuntimeContext):
     def __init__(self, ctx_auth):
         self.__service_root_url = "https://outlook.office365.com/api/v1.0/"
         super(OutlookClient, self).__init__(self.__service_root_url, ctx_auth)
-        self.json_format = V4JsonFormat("minimal")
+        self._pendingRequest = ODataRequest(self, V4JsonFormat("minimal"))
+        self._pendingRequest.beforeExecute += self._build_specific_query
 
-    def execute_query(self):
-        self.pending_request.before_execute_request(self._build_specific_query)
-        super(OutlookClient, self).execute_query()
+    def get_pending_request(self):
+        return self._pendingRequest
 
     @staticmethod
     def _build_specific_query(request, query):
