@@ -30,9 +30,6 @@ class CamlQuery(ClientValueObject):
         qry.ViewXml = query
         return qry
 
-    def to_json(self, data_format):
-        return {"query": super(CamlQuery, self).to_json(data_format)}
-
     @property
-    def typeName(self):
+    def entityTypeName(self):
         return 'SP.CamlQuery'
