@@ -1,7 +1,7 @@
 from office365.runtime.client_query import UpdateEntityQuery, DeleteEntityQuery, ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
-from office365.runtime.utilities.http_method import HttpMethod
+from office365.runtime.http.http_method import HttpMethod
 from office365.sharepoint.securable_object import SecurableObject
 
 
@@ -79,9 +79,10 @@ class ListItem(SecurableObject):
             return AttachmentfileCollection(self.context,
                                             ResourcePath("AttachmentFiles", self.resourcePath))
 
-    def set_property(self, name, value, serializable=True):
-        super(ListItem, self).set_property(name, value, serializable)
+    def set_property(self, name, value, persist_changes=True):
+        super(ListItem, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
-        if name == "Id" and self._resource_path is None:
-            self._resource_path = ResourcePathServiceOperation(
-                "getItemById", [value], self._parent_collection.resourcePath)
+        if self._resource_path is None:
+            if name == "Id":
+                self._resource_path = ResourcePathServiceOperation(
+                    "getItemById", [value], self._parent_collection.resourcePath.parent)
