@@ -1,5 +1,6 @@
 from office365.runtime.client_object import ClientObject
 from office365.runtime.resource_path import ResourcePath
+from office365.sharepoint.user import User
 from office365.sharepoint.web import Web
 
 
@@ -16,3 +17,11 @@ class Site(ClientObject):
             return self.properties['RootWeb']
         else:
             return Web(self.context, ResourcePath("RootWeb", self.resourcePath))
+
+    @property
+    def owner(self):
+        """Gets or sets the owner of the site collection. (Read-only in sandboxed solutions.)"""
+        if self.is_property_available('owner'):
+            return self.properties['owner']
+        else:
+            return User(self.context, ResourcePath("owner", self.resourcePath))
