@@ -1,23 +1,21 @@
 from tests import random_seed
 from tests.sharepoint_case import SPTestCase
-from tests.test_utilities import ListExtensions
-
 from office365.sharepoint.list_creation_information import ListCreationInformation
 from office365.sharepoint.list_template_type import ListTemplateType
+from tests.test_methods import ensure_list
 
 
 class TestSharePointListItem(SPTestCase):
-
     target_list = None
 
     @classmethod
     def setUpClass(cls):
         super(TestSharePointListItem, cls).setUpClass()
-        cls.target_list = ListExtensions.ensure_list(cls.client.web,
-                                                     ListCreationInformation("Tasks",
-                                                                             None,
-                                                                             ListTemplateType.Tasks)
-                                                     )
+        cls.target_list = ensure_list(cls.client.web,
+                                      ListCreationInformation("Tasks",
+                                                              None,
+                                                              ListTemplateType.Tasks)
+                                      )
         cls.target_item_properties = {
             "Title": "Task %s" % random_seed,
             "Id": None
@@ -29,7 +27,8 @@ class TestSharePointListItem(SPTestCase):
         cls.client.execute_query()
 
     def test_1_create_list_item(self):
-        item_properties = {'Title': self.target_item_properties["Title"], '__metadata': {'type': 'SP.Data.TasksListItem'}}
+        item_properties = {'Title': self.target_item_properties["Title"],
+                           '__metadata': {'type': 'SP.Data.TasksListItem'}}
         item = self.target_list.add_item(item_properties)
         self.client.execute_query()
         self.assertIsNotNone(item.properties["Title"])
